@@ -1,4 +1,4 @@
-/* $XdotOrg: xc/programs/xdm/session.c,v 1.1.4.4 2003/12/06 13:24:29 kaleb Exp $ */
+/* $XdotOrg: app/xdm/session.c,v 1.5 2006/03/16 21:46:55 alanc Exp $ */
 /* $Xorg: session.c,v 1.8 2001/02/09 02:05:40 xorgcvs Exp $ */
 /*
 
@@ -55,12 +55,18 @@ from The Open Group.
 #ifdef SECURE_RPC
 # include <rpc/rpc.h>
 # include <rpc/key_prot.h>
+# if !HAVE_DECL_KEY_SETNET
 extern int key_setnet(struct key_netstarg *arg);
+# endif
 #endif
 #ifdef K5AUTH
 # include <krb5/krb5.h>
 #endif
 
+#ifdef __SCO__
+#include <prot.h>
+#endif
+
 #ifndef GREET_USER_STATIC
 # include <dlfcn.h>
 # ifndef RTLD_NOW
@@ -70,7 +76,7 @@ extern int key_setnet(struct key_netstarg *arg);
 
 static	int	runAndWait (char **args, char **environ);
 
-#if defined(CSRG_BASED) || defined(__osf__) || defined(__DARWIN__) || defined(__QNXNTO__) || defined(sun) || defined(__GLIBC__)
+#ifdef HAVE_GRP_H
 # include <sys/types.h>
 # include <grp.h>
 #else
@@ -88,7 +94,7 @@ extern	struct spwd	*getspnam(GETSPNAM_ARGS);
 extern	void	endspent(void);
 # endif
 #endif
-#if defined(CSRG_BASED) || defined(__GLIBC__) || defined(USL)
+#if defined(CSRG_BASED) || defined(__GLIBC__) || defined(__UNIXWARE__) || defined(__SCO__)
 # include <pwd.h>
 # include <unistd.h>
 #else
@@ -534,6 +540,11 @@ StartClient (
     pam_handle_t *pamh = thepamh ();
     int	pam_error;
 #endif
+#ifdef USESECUREWARE
+    char *reason, **smpenv, *smpshell;
+    int ret;
+    extern struct smp_user_info *userp;
+#endif
 
     if (verify->argv) {
 	Debug ("StartSession %s: ", verify->argv[0]);
@@ -570,6 +581,35 @@ StartClient (
 	}
 #endif
 
+#ifdef USESECUREWARE
+        Debug ("set_identity: uid=%d\n", userp->pw.pw_uid);
+        ret = smp_set_identity (userp, &reason, &smpenv, &smpshell);
+        Debug ("smp_set_identity returns %d luid=%d\n", ret, getluid());
+        switch (ret) {
+          case SMP_FAIL:
+            LogError ("Unable to set identity\n");
+            smp_audit_fail (userp, 0);
+            return 0;
+          case SMP_EXTFAIL:
+            LogError ("Unable to set identity: %s\n", reason);
+            smp_audit_fail (userp, 0);
+            return 0;
+          case SMP_NOTAUTH:
+            LogError ("Authorization failed\n");
+            smp_audit_fail (userp, 0);
+            return 0;
+          case SMP_ACCTLOCK:
+            LogError ("Account is locked\n");
+            smp_audit_fail (userp, 0);
+            return 0;
+          case SMP_COMPLETE:
+            break;
+          default:
+            LogError ("Unhandled identity error %d\n", ret);
+            smp_audit_fail (userp, 0);
+            return 0;
+        }
+#endif
 
 #ifndef AIXV3
 #ifndef HAS_SETUSERCONTEXT
@@ -911,7 +951,7 @@ systemEnv (struct display *d, char *user, char *home)
     return env;
 }
 
-#if (defined(Lynx) && !defined(HAS_CRYPT)) || defined(SCO) && !defined(SCO_USA) && !defined(_SCO_DS)
+#if (defined(Lynx) && !defined(HAS_CRYPT))
 char *crypt(char *s1, char *s2)
 {
 	return(s2);
